@@ -57,7 +57,7 @@ mo_location = LOCALE_DIR
 
 # Lets tell those details to gettext
 #  (nothing to change here for you)
-gettext.install (True)
+gettext.install (True,localedir=None, unicode=1)
 
 
 #gettext.bindtextdomain (APP_NAME,mo_location)
@@ -67,7 +67,7 @@ gettext.find(APP_NAME, mo_location)
 
 gettext.textdomain (APP_NAME)
 
-#gettext.bind_textdomain_codeset(APP_NAME, "iso-8859-15")
+gettext.bind_textdomain_codeset(APP_NAME, "iso-8859-15")
 
 #language = gettext.translation (APP_NAME, mo_location, languages = languages, fallback = True)
 language = gettext.translation (APP_NAME, mo_location, languages = languages, fallback = True)
