@@ -66,7 +66,8 @@ if(len(sys.argv)>1):  #at least one parameter
 
 #load language file
 import i18n
-_ = i18n.language.gettext
+#_ = i18n.language.gettext
+_ = i18n.language.ugettext
 
 ########################################
 
@@ -451,7 +452,7 @@ def About(ui):
     _("Feedback and donations are very welcome!")+"\n\n"+\
     _("Translations:")+\
     "\nEnglish, Deutsch: George Ruinelli\n"+\
-    "Francais: Fred Kwame Ayanful")
+    "Francais, Dutch: Fred Kwame Ayanful")
 
 
 
@@ -1645,12 +1646,12 @@ class frmAdditionalInfoWindow(QMainWindow):
         "<b>"+_("Date/Time:")+"</b> "+QtGui.QApplication.translate("", d0, None, QtGui.QApplication.UnicodeUTF8)+" - "+d1+"<br>" + \
         "<b>"+_("Duration:")+"</b> "+ diff+"<br>" + \
         "<b>"+_("Note:")+"</b> "+QtGui.QApplication.translate("", records.Note, None, QtGui.QApplication.UnicodeUTF8)+"<br>" + \
-        "<b>"+_("User:")+"</b> "+QtGui.QApplication.translate("", records.User, None, QtGui.QApplication.UnicodeUTF8) +"<br>" + \
+        "<b>"+_("User name:")+"</b> "+QtGui.QApplication.translate("", records.User, None, QtGui.QApplication.UnicodeUTF8) +"<br>" + \
         "<b>"+_("Record entries:")+"</b> "+str(records.Index)+" (1/"+str(int(records.Sampling_interval*records.Value_smoothing/1000))+" "+_("seconds")+")<br>" +\
         "<b>"+_("Record version:")+"</b> "+str(records.SWversion) + "<br>" + \
         alarm +\
         "<b>"+_("Trigger level:")+"</b> "+str(records.Trigger) + "<br>" + \
-        "<b>"+_("Condition of record:")+"</b> "+str(records.status) + "<br>"
+        "<b>"+_("Condition of record:")+"</b> "+QtGui.QApplication.translate("", records.status, None, QtGui.QApplication.UnicodeUTF8) + "<br>"
 
 
 
